<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Copyright © 2011–%1 Markus Enzenberger</source>
        <translation>版权所有 2011–%1 Markus Enzenberger</translation>
    </message>
    <message>
        <source>Computer opponent for the board game Blokus</source>
        <translation>经典桌游《角斗士》的计算机对手</translation>
    </message>
    <message>
        <source>Pentobi %1</source>
        <extracomment>The argument is the application version.</extracomment>
        <translation>Pentobi 版本%1</translation>
    </message>
</context>
<context>
    <name>AnalyzeDialog</name>
    <message>
        <source>Analysis speed:</source>
        <translation>分析速度：</translation>
    </message>
    <message>
        <source>Fast</source>
        <translation>快速</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>中速</translation>
    </message>
    <message>
        <source>Slow</source>
        <translation>慢速</translation>
    </message>
</context>
<context>
    <name>AnalyzeGame</name>
    <message>
        <source>(No analysis)</source>
        <translation>（暂无分析）</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Coordinates</source>
        <translation>坐标</translation>
    </message>
    <message>
        <source>Show variations</source>
        <translation>显示变化</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>浅色</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>深色</translation>
    </message>
    <message>
        <source>Colorblind light</source>
        <translation>色盲浅</translation>
    </message>
    <message>
        <source>Colorblind dark</source>
        <translation>色盲深</translation>
    </message>
    <message>
        <source>System</source>
        <extracomment>Name of theme using default system colors</extracomment>
        <translation>系统</translation>
    </message>
    <message>
        <source>Move marking:</source>
        <translation>棋步标记：</translation>
    </message>
    <message>
        <source>Last with dot</source>
        <translation>最后一步加点</translation>
    </message>
    <message>
        <source>Last with number</source>
        <translation>最后一步加数字</translation>
    </message>
    <message>
        <source>All with number</source>
        <translation>所有棋步加点</translation>
    </message>
    <message>
        <source>None</source>
        <extracomment>Move marking/None</extracomment>
        <translation>无</translation>
    </message>
    <message>
        <source>Animations</source>
        <translation>动画</translation>
    </message>
    <message>
        <source>Show comment:</source>
        <translation>显示注解：</translation>
    </message>
    <message>
        <source>Always</source>
        <extracomment>Show-comment mode</extracomment>
        <translation>总是</translation>
    </message>
    <message>
        <source>As needed</source>
        <extracomment>Show-comment mode</extracomment>
        <translation>按需</translation>
    </message>
    <message>
        <source>Never</source>
        <extracomment>Show-comment mode</extracomment>
        <translation>不显示</translation>
    </message>
    <message>
        <source>Color theme:</source>
        <translation>颜色主题：</translation>
    </message>
    <message>
        <source>Move number</source>
        <extracomment>Check box in appearance dialog whether to show the move number in the status bar.</extracomment>
        <translation>棋步顺序</translation>
    </message>
</context>
<context>
    <name>AsciiArtSaveDialog</name>
    <message>
        <source>Export ASCII Art</source>
        <translation>导出字符画</translation>
    </message>
    <message>
        <source>Text files</source>
        <translation>文本文件</translation>
    </message>
</context>
<context>
    <name>BoardContextMenu</name>
    <message>
        <source>Go to Move %1</source>
        <translation>转到第%1步</translation>
    </message>
    <message>
        <source>Move Annotation</source>
        <translation>棋步注解</translation>
    </message>
    <message>
        <source>Move Annotation (%1)</source>
        <extracomment>The argument is the annotation symbol for the current move</extracomment>
        <translation>棋步注解（%1）</translation>
    </message>
</context>
<context>
    <name>ButtonApply</name>
    <message>
        <source>Apply</source>
        <translation>应用</translation>
    </message>
</context>
<context>
    <name>ButtonCancel</name>
    <message>
        <source>Cancel</source>
        <translation>取消</translation>
    </message>
</context>
<context>
    <name>ButtonClose</name>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
</context>
<context>
    <name>ButtonOk</name>
    <message>
        <source>OK</source>
        <translation>确定</translation>
    </message>
</context>
<context>
    <name>ComputerDialog</name>
    <message>
        <source>Computer plays:</source>
        <translation>电脑执：</translation>
    </message>
    <message>
        <source>Level %1</source>
        <translation>等级 %1</translation>
    </message>
</context>
<context>
    <name>DocbookReader</name>
    <message>
        <source>Previous</source>
        <extracomment>Go to previous page of user manual</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Contents</source>
        <extracomment>Go to table of contents of user manual</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Next</source>
        <extracomment>Go to next page of user manual</extracomment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ExportImageDialog</name>
    <message>
        <source>Image width:</source>
        <translation>图像宽度：</translation>
    </message>
</context>
<context>
    <name>GameInfoDialog</name>
    <message>
        <source>Player Blue/Red:</source>
        <translation>玩家 蓝/红：</translation>
    </message>
    <message>
        <source>Player Purple:</source>
        <translation>玩家 紫色：</translation>
    </message>
    <message>
        <source>Player Green:</source>
        <translation>玩家 绿色：</translation>
    </message>
    <message>
        <source>Player Blue:</source>
        <translation>玩家 蓝色：</translation>
    </message>
    <message>
        <source>Player Yellow/Green:</source>
        <translation>玩家 黄/绿：</translation>
    </message>
    <message>
        <source>Player Orange:</source>
        <translation>玩家 橙色：</translation>
    </message>
    <message>
        <source>Player Yellow:</source>
        <translation>玩家 黄色：</translation>
    </message>
    <message>
        <source>Player Red:</source>
        <translation>玩家 红色：</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>日期：</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>时间：</translation>
    </message>
    <message>
        <source>Event:</source>
        <translation>赛事：</translation>
    </message>
    <message>
        <source>Round:</source>
        <translation>轮次：</translation>
    </message>
</context>
<context>
    <name>GameModel</name>
    <message>
        <source>Purple wins with 1 point.</source>
        <translation>紫色赢1分。</translation>
    </message>
    <message>
        <source>Purple wins with %L1 points.</source>
        <translation>紫色赢%L1分。</translation>
    </message>
    <message>
        <source>Orange wins with 1 point.</source>
        <translation>橙色赢1分。</translation>
    </message>
    <message>
        <source>Orange wins with %L1 points.</source>
        <translation>橙色赢%L1分。</translation>
    </message>
    <message>
        <source>Game ends in a tie.</source>
        <translation>本局以平局结束。</translation>
    </message>
    <message>
        <source>Green wins with 1 point.</source>
        <translation>绿色赢1分。</translation>
    </message>
    <message>
        <source>Green wins with %L1 points.</source>
        <translation>绿色赢%L1分。</translation>
    </message>
    <message>
        <source>Blue wins with 1 point.</source>
        <translation>蓝色赢1分。</translation>
    </message>
    <message>
        <source>Blue wins with %L1 points.</source>
        <translation>蓝色赢%L1分。</translation>
    </message>
    <message>
        <source>Green wins (tie resolved).</source>
        <extracomment>Game variant with tie-breaker rule made later player win.</extracomment>
        <translation>绿色 获胜（平局后）。</translation>
    </message>
    <message>
        <source>Blue/Red wins with 1 point.</source>
        <translation>蓝/红 赢1分。</translation>
    </message>
    <message>
        <source>Blue/Red wins with %L1 points.</source>
        <translation>蓝/红 赢%L1分。</translation>
    </message>
    <message>
        <source>Yellow/Green wins with 1 point.</source>
        <translation>黄/绿 赢1分。</translation>
    </message>
    <message>
        <source>Yellow/Green wins with %L1 points.</source>
        <translation>黄/绿 赢%L1分。</translation>
    </message>
    <message>
        <source>Yellow/Green wins (tie resolved).</source>
        <extracomment>Game variant with tie-breaker rule made later player win.</extracomment>
        <translation>黄/绿 获胜（平局后）。</translation>
    </message>
    <message>
        <source>Blue wins.</source>
        <translation>蓝色 获胜。</translation>
    </message>
    <message>
        <source>Yellow wins.</source>
        <translation>黄色 获胜。</translation>
    </message>
    <message>
        <source>Red wins.</source>
        <translation>红色 获胜。</translation>
    </message>
    <message>
        <source>Red wins (tie resolved).</source>
        <extracomment>Game variant with tie-breaker rule made later player win.</extracomment>
        <translation>红色 获胜（平局后）。</translation>
    </message>
    <message>
        <source>Yellow wins (tie resolved).</source>
        <extracomment>Game variant with tie-breaker rule made later player win.</extracomment>
        <translation>黄色 获胜（平局后）。</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue and Yellow.</source>
        <translation>蓝色与黄色共同获胜。</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue and Red.</source>
        <translation>蓝色与红色共同获胜。</translation>
    </message>
    <message>
        <source>Game ends in a tie between Yellow and Red.</source>
        <translation>红色与黄色共同获胜。</translation>
    </message>
    <message>
        <source>Game ends in a tie between all players.</source>
        <translation>所有玩家平局。</translation>
    </message>
    <message>
        <source>Green wins.</source>
        <translation>绿色 获胜。</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue, Yellow and Red.</source>
        <translation>蓝色、黄色与红色共同获胜。</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue, Yellow and Green.</source>
        <translation>蓝色、黄色与绿色共同获胜。</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue, Red and Green.</source>
        <translation>蓝色、红色与绿色共同获胜。</translation>
    </message>
    <message>
        <source>Game ends in a tie between Yellow, Red and Green.</source>
        <translation>黄色、红色与绿色共同获胜。</translation>
    </message>
    <message>
        <source>Invalid Blokus SGF file. (%1)</source>
        <translation>无效的角斗士游戏文件。（%1）</translation>
    </message>
    <message>
        <source>Clipboard is empty.</source>
        <translation>剪贴板为空。</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>无标题</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <extracomment>The argument is a number, which will be increased if a file with the same name already exists</extracomment>
        <translation>无标题%1</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>新文件夹</translation>
    </message>
    <message>
        <source>New Folder %1</source>
        <extracomment>The argument is a number, which will be increased if a folder with the same name already exists</extracomment>
        <translation>新文件夹%1</translation>
    </message>
    <message>
        <source>(Setup)</source>
        <translation>（设置模式）</translation>
    </message>
    <message>
        <source>(No moves)</source>
        <translation>（无棋步）</translation>
    </message>
    <message>
        <source>Move %1</source>
        <extracomment>The argument is the current move number.</extracomment>
        <translation>棋步 %1</translation>
    </message>
    <message>
        <source>Unsupported character set</source>
        <translation>不支持的字符集</translation>
    </message>
</context>
<context>
    <name>GameVariantDialog</name>
    <message>
        <source>Classic</source>
        <translation>经典</translation>
    </message>
    <message>
        <source>Duo</source>
        <translation>双人</translation>
    </message>
    <message>
        <source>Junior</source>
        <translation>初级</translation>
    </message>
    <message>
        <source>Trigon</source>
        <translation>六角</translation>
    </message>
    <message>
        <source>Nexos</source>
        <translation>线</translation>
    </message>
    <message>
        <source>GembloQ</source>
        <translation>宝石阵Q</translation>
    </message>
    <message>
        <source>Callisto</source>
        <translation>八角</translation>
    </message>
    <message>
        <source>Players:</source>
        <translation>玩家：</translation>
    </message>
    <message>
        <source>Colors:</source>
        <translation>颜色：</translation>
    </message>
</context>
<context>
    <name>GameViewDesktop</name>
    <message>
        <source>Computer is thinking…</source>
        <translation>电脑正在思考…</translation>
    </message>
    <message>
        <source>Running game analysis…</source>
        <translation>正在进行棋局分析…</translation>
    </message>
    <message>
        <source>Computer is thinking… (up to %1 seconds remaining)</source>
        <translation>电脑正在思考...（最多剩余%1秒）</translation>
    </message>
    <message>
        <source>Computer is thinking… (up to %1 minutes remaining)</source>
        <translation>电脑正在思考...(最多剩余%1分)</translation>
    </message>
</context>
<context>
    <name>GotoMoveDialog</name>
    <message>
        <source>Move number:</source>
        <translation>棋步序号：</translation>
    </message>
</context>
<context>
    <name>HelpWindow</name>
    <message>
        <source>Pentobi Help</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ImageSaveDialog</name>
    <message>
        <source>Save Image</source>
        <translation>保存图片</translation>
    </message>
    <message>
        <source>PNG image files</source>
        <translation>PNG图像文件</translation>
    </message>
    <message>
        <source>JPEG image files</source>
        <translation>JPEG图像文件</translation>
    </message>
</context>
<context>
    <name>InitialRatingDialog</name>
    <message>
        <source>Initialize your rating for this game variant.</source>
        <translation>设置您在本游戏规则下的初始等级。</translation>
    </message>
    <message>
        <source>Initial rating:</source>
        <translation>初始等级：</translation>
    </message>
    <message>
        <source>Beginner</source>
        <translation>初学者</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation>专家</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Pentobi</source>
        <extracomment>Window title if no file is loaded.</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Game analysis is only possible in main variation.</source>
        <translation>棋局分析只能在主变化中进行。</translation>
    </message>
    <message>
        <source>Autosaved game was changed by another instance of Pentobi. Overwrite?</source>
        <translation>自动保存的棋局被另一个程序实例更改。要覆盖吗？</translation>
    </message>
    <message>
        <source>Your rating has increased from %1 to %2.</source>
        <translation>您的等级从%1升到%2。</translation>
    </message>
    <message>
        <source>Your rating has decreased from %1 to %2.</source>
        <translation>您的等级从%1降到%2。</translation>
    </message>
    <message>
        <source>Your rating stays at %1.</source>
        <translation>您的等级仍然是%1。</translation>
    </message>
    <message>
        <source>Delete all rating information for the current game variant?</source>
        <translation>删除此游戏规则下的所有等级数据？</translation>
    </message>
    <message>
        <source>Delete all variations?</source>
        <translation>删除所有变例？</translation>
    </message>
    <message>
        <source>Save failed.</source>
        <translation>保存失败。</translation>
    </message>
    <message>
        <source>End of tree was reached. Continue search from start of the tree?</source>
        <translation>已经到达棋局树的最末端。从树的开头继续搜索？</translation>
    </message>
    <message>
        <source>No comment found</source>
        <translation>无注解</translation>
    </message>
    <message>
        <source>%1 (modified)</source>
        <extracomment>Label for modified loaded game. The argument is the file name.</extracomment>
        <translation>%1 （已修改）</translation>
    </message>
    <message>
        <source>File has been modified by another application. Reload?</source>
        <translation>文件被其他程序修改。重新加载吗？</translation>
    </message>
    <message>
        <source>Continue computer move?</source>
        <translation>是否由电脑继续行棋？</translation>
    </message>
    <message>
        <source>Keep only position?</source>
        <translation>只保留棋子位置吗？</translation>
    </message>
    <message>
        <source>Keep only subtree?</source>
        <translation>只保留子树吗？</translation>
    </message>
    <message>
        <source>Open failed.</source>
        <translation>打开失败。</translation>
    </message>
    <message>
        <source>Start rated game with Purple against Pentobi level %1?</source>
        <translation>是否开始等级赛，你执紫色，对阵级别%1的电脑？</translation>
    </message>
    <message>
        <source>Start rated game with Green against Pentobi level %1?</source>
        <translation>是否开始等级赛，你执绿色，对阵级别%1的电脑？</translation>
    </message>
    <message>
        <source>Start rated game with Blue/Red against Pentobi level %1?</source>
        <translation>是否开始等级赛，你执蓝/红，对阵级别%1的电脑？</translation>
    </message>
    <message>
        <source>Start rated game with Blue against Pentobi level %1?</source>
        <translation>是否开始等级赛，你执蓝色，对阵级别%1的电脑？</translation>
    </message>
    <message>
        <source>Start rated game with Orange against Pentobi level %1?</source>
        <translation>是否开始等级赛，你执橙色，对阵级别%1的电脑？</translation>
    </message>
    <message>
        <source>Start rated game with Yellow/Green against Pentobi level %1?</source>
        <translation>是否开始等级赛，你执黄/绿，对阵级别%1的电脑？</translation>
    </message>
    <message>
        <source>Start rated game with Yellow against Pentobi level %1?</source>
        <translation>是否开始等级赛，你执黄色，对阵级别%1的电脑？</translation>
    </message>
    <message>
        <source>Start rated game with Red against Pentobi level %1?</source>
        <translation>是否开始等级赛，你执红色，对阵级别%1的电脑？</translation>
    </message>
    <message>
        <source>You have not yet played rated games in this game variant.</source>
        <translation>在此规则下，您还没有玩过等级赛。</translation>
    </message>
    <message>
        <source>Truncate this subtree?</source>
        <translation>截断此子树？</translation>
    </message>
    <message>
        <source>Truncate children?</source>
        <translation>截断此结点下面的子结点？</translation>
    </message>
    <message>
        <source>Discard game?</source>
        <translation>丢弃本局吗？</translation>
    </message>
    <message>
        <source>Pentobi %1 (level %2)</source>
        <extracomment>Player name for game info in rated game. First argument is version of Pentobi, second argument is level.</extracomment>
        <translation>Pentobi 版本%1（级别%2）</translation>
    </message>
    <message>
        <source>Human</source>
        <extracomment>Player name for game info in rated game.</extracomment>
        <translation>人脑</translation>
    </message>
    <message>
        <source>Rated game</source>
        <translation>等级赛</translation>
    </message>
    <message>
        <source>File has been modified by another application. Overwrite?</source>
        <translation>文件已被其他程序修改。覆盖吗？</translation>
    </message>
    <message>
        <source>%1 - Pentobi</source>
        <extracomment>Window title if file is loaded. The argument is the file name prepended with a star if the file has been modified.</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not enough memory</source>
        <translation>内存不足</translation>
    </message>
    <message>
        <source>Game analysis aborted</source>
        <translation>棋局分析被取消</translation>
    </message>
    <message>
        <source>Computer move aborted</source>
        <translation>电脑行棋被取消</translation>
    </message>
    <message>
        <source>Rating information deleted</source>
        <translation>等级数据已删除</translation>
    </message>
    <message>
        <source>Variations deleted</source>
        <translation>变例已删除</translation>
    </message>
    <message>
        <source>File saved</source>
        <translation>文件已保存</translation>
    </message>
    <message>
        <source>Saving image failed or unsupported image format</source>
        <translation>图像保存失败，或不支持的图像格式</translation>
    </message>
    <message>
        <source>Image saved</source>
        <translation>图像已保存</translation>
    </message>
    <message>
        <source>Creating image failed</source>
        <translation>图像创建失败</translation>
    </message>
    <message>
        <source>Continuing rated game</source>
        <translation>继续等级赛</translation>
    </message>
    <message>
        <source>Kept only position</source>
        <translation>只保留棋子位置</translation>
    </message>
    <message>
        <source>Kept only subtree</source>
        <translation>只保留子树</translation>
    </message>
    <message>
        <source>Variation is now %1</source>
        <translation>当前变例为 %1</translation>
    </message>
    <message>
        <source>Children truncated</source>
        <translation>子结点已截断</translation>
    </message>
    <message>
        <source>Setup</source>
        <extracomment>Small-screen label for setup mode (short for &quot;Setup Mode&quot;).</extracomment>
        <translation>设置模式</translation>
    </message>
    <message>
        <source>Setup Mode</source>
        <translation>设置模式</translation>
    </message>
    <message>
        <source>Rated</source>
        <extracomment>Label for ongoing rated game</extracomment>
        <translation>等级赛</translation>
    </message>
    <message>
        <source>Rated %1</source>
        <extracomment>Small-screen label for finished rated game (short for &quot;Rated Game&quot;). The argument is the game number.</extracomment>
        <translation>等级赛 第%1局</translation>
    </message>
    <message>
        <source>Rated Game %1</source>
        <extracomment>Label for rated game. The argument is the game number.</extracomment>
        <translation>等级赛 第%1局</translation>
    </message>
    <message>
        <source>Main Variation</source>
        <translation>主变例</translation>
    </message>
    <message>
        <source>Beginning of Branch</source>
        <translation>分支的开始</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>注解</translation>
    </message>
    <message>
        <source>Settings</source>
        <extracomment>Menu item Computer/Settings</extracomment>
        <translation>设置</translation>
    </message>
    <message>
        <source>Find Move</source>
        <translation>寻找棋步</translation>
    </message>
    <message>
        <source>Next Comment</source>
        <translation>下一个注解</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全屏幕</translation>
    </message>
    <message>
        <source>Game Info</source>
        <translation>棋局信息</translation>
    </message>
    <message>
        <source>Move Number…</source>
        <translation>指定棋步…</translation>
    </message>
    <message>
        <source>Pentobi Help</source>
        <translation>Pentobi 帮助</translation>
    </message>
    <message>
        <source>New</source>
        <translation>新棋局</translation>
    </message>
    <message>
        <source>Rated Game</source>
        <translation>等级赛</translation>
    </message>
    <message>
        <source>Open…</source>
        <translation>打开…</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>行棋</translation>
    </message>
    <message>
        <source>Play Move</source>
        <extracomment>Play a single move</extracomment>
        <translation>走一步</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>退出</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Save As…</source>
        <translation>另存为…</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Undo Move</source>
        <translation>撤销一步</translation>
    </message>
    <message>
        <source>Blue/Red</source>
        <translation>蓝/红</translation>
    </message>
    <message>
        <source>Purple</source>
        <translation>紫色</translation>
    </message>
    <message>
        <source>Green</source>
        <translation>绿色</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation>蓝色</translation>
    </message>
    <message>
        <source>Yellow/Green</source>
        <translation>黄/绿</translation>
    </message>
    <message>
        <source>Orange</source>
        <translation>橙色</translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation>黄色</translation>
    </message>
    <message>
        <source>Red</source>
        <translation>红色</translation>
    </message>
    <message>
        <source>Pentobi failed to generate a move.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Press back again to exit</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MenuComputer</name>
    <message>
        <source>Computer</source>
        <translation>电脑</translation>
    </message>
</context>
<context>
    <name>MenuEdit</name>
    <message>
        <source>Edit</source>
        <translation>编辑</translation>
    </message>
    <message>
        <source>Make Main Variation</source>
        <translation>设为主变例</translation>
    </message>
    <message>
        <source>Variation Up</source>
        <extracomment>Short for Move Variation Up</extracomment>
        <translation>上一变例</translation>
    </message>
    <message>
        <source>Variation Down</source>
        <extracomment>Short for Move Variation Down</extracomment>
        <translation>下一变例</translation>
    </message>
    <message>
        <source>Delete Variations</source>
        <translation>删除所有变例</translation>
    </message>
    <message>
        <source>Truncate</source>
        <translation>截断</translation>
    </message>
    <message>
        <source>Truncate Children</source>
        <translation>截断子结点</translation>
    </message>
    <message>
        <source>Keep Position</source>
        <translation>保存棋子位置</translation>
    </message>
    <message>
        <source>Keep Subtree</source>
        <translation>保留子树</translation>
    </message>
    <message>
        <source>Setup Mode</source>
        <translation>设置模式</translation>
    </message>
    <message>
        <source>Next Color</source>
        <translation>轮到的颜色</translation>
    </message>
    <message>
        <source>Annotation…</source>
        <translation>注解…</translation>
    </message>
    <message>
        <source>Made main variation</source>
        <translation>已设为主变例</translation>
    </message>
</context>
<context>
    <name>MenuExport</name>
    <message>
        <source>Export</source>
        <translation>导出</translation>
    </message>
    <message>
        <source>Image…</source>
        <translation>图像…</translation>
    </message>
    <message>
        <source>ASCII Art…</source>
        <translation>字符画…</translation>
    </message>
</context>
<context>
    <name>MenuGame</name>
    <message>
        <source>Game</source>
        <translation>棋局</translation>
    </message>
    <message>
        <source>Game Variant…</source>
        <translation>游戏规则…</translation>
    </message>
    <message>
        <source>Open Clipboard</source>
        <translation>打开剪贴板</translation>
    </message>
</context>
<context>
    <name>MenuGo</name>
    <message>
        <source>Go</source>
        <translation>转到</translation>
    </message>
</context>
<context>
    <name>MenuHelp</name>
    <message>
        <source>Help</source>
        <translation>帮助</translation>
    </message>
    <message>
        <source>About Pentobi</source>
        <translation>关于</translation>
    </message>
    <message>
        <source>Report Bug</source>
        <translation>报告bug</translation>
    </message>
</context>
<context>
    <name>MenuRecentFiles</name>
    <message>
        <source>Open Recent</source>
        <translation>打开最近文件</translation>
    </message>
    <message>
        <source>Clear List</source>
        <extracomment>Menu item for clearing the recent files list</extracomment>
        <translation>清除列表</translation>
    </message>
</context>
<context>
    <name>MenuTools</name>
    <message>
        <source>Tools</source>
        <translation>工具</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>等级分</translation>
    </message>
    <message>
        <source>Clear Rating</source>
        <translation>清除等级分</translation>
    </message>
    <message>
        <source>Clear Analysis</source>
        <translation>清除分析</translation>
    </message>
    <message>
        <source>Analyze Game…</source>
        <translation>分析棋局…</translation>
    </message>
</context>
<context>
    <name>MenuView</name>
    <message>
        <source>View</source>
        <translation>视图</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>界面</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>工具栏</translation>
    </message>
</context>
<context>
    <name>MoveAnnotationDialog</name>
    <message>
        <source>Move %1</source>
        <translation>棋步 %1</translation>
    </message>
    <message>
        <source>Very good</source>
        <translation>妙招</translation>
    </message>
    <message>
        <source>Good</source>
        <translation>好棋</translation>
    </message>
    <message>
        <source>Interesting</source>
        <translation>有趣</translation>
    </message>
    <message>
        <source>Doubtful</source>
        <translation>争议</translation>
    </message>
    <message>
        <source>Bad</source>
        <translation>坏棋</translation>
    </message>
    <message>
        <source>Very Bad</source>
        <translation>败招</translation>
    </message>
    <message>
        <source>No annotation</source>
        <translation>无注解</translation>
    </message>
</context>
<context>
    <name>NewFolderDialog</name>
    <message>
        <source>Folder name:</source>
        <translation>文件夹名：</translation>
    </message>
</context>
<context>
    <name>OpenDialog</name>
    <message>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <source>Blokus games</source>
        <translation>角斗士游戏</translation>
    </message>
</context>
<context>
    <name>PentobiFileDialog</name>
    <message>
        <source>Overwrite file?</source>
        <translation>覆盖文件？</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>所有文件</translation>
    </message>
</context>
<context>
    <name>PentobiMenuItem</name>
    <message>
        <source>Ctrl</source>
        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shift</source>
        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PentobiToolBar</name>
    <message>
        <source>Start a new game</source>
        <translation>开始新游戏</translation>
    </message>
    <message>
        <source>Start a rated game</source>
        <translation>开始一局等级赛</translation>
    </message>
    <message>
        <source>Set the colors played by the computer</source>
        <translation>设置电脑控制的颜色</translation>
    </message>
    <message>
        <source>Make the computer continue to play the current color</source>
        <translation>使电脑执当前颜色继续</translation>
    </message>
    <message>
        <source>Make the computer play the current color</source>
        <translation>使电脑执当前颜色</translation>
    </message>
    <message>
        <source>Go to beginning of game</source>
        <translation>转到棋局开始</translation>
    </message>
    <message>
        <source>Go ten moves backward</source>
        <translation>向后跳转10步</translation>
    </message>
    <message>
        <source>Go one move backward</source>
        <translation>向后跳转一步</translation>
    </message>
    <message>
        <source>Go one move forward</source>
        <translation>向前跳转一步</translation>
    </message>
    <message>
        <source>Go ten moves forward</source>
        <translation>向前跳转10步</translation>
    </message>
    <message>
        <source>Go to end of moves</source>
        <translation>转到棋局末尾</translation>
    </message>
    <message>
        <source>Go to previous variation</source>
        <translation>转到上一变例</translation>
    </message>
    <message>
        <source>Go to next variation</source>
        <translation>转到下一变例</translation>
    </message>
    <message>
        <source>Abort game analysis</source>
        <translation>取消棋局分析</translation>
    </message>
    <message>
        <source>Abort computer move</source>
        <translation>取消电脑行棋</translation>
    </message>
    <message>
        <source>Undo move</source>
        <extracomment>Tooltip for Undo button</extracomment>
        <translation>撤销一步</translation>
    </message>
    <message>
        <source>Open menu</source>
        <translation>打开菜单</translation>
    </message>
</context>
<context>
    <name>RatingDialog</name>
    <message>
        <source>Your rating:</source>
        <translation>您的等级分：</translation>
    </message>
    <message>
        <source>Game variant:</source>
        <translation>游戏规则：</translation>
    </message>
    <message>
        <source>Classic (2)</source>
        <extracomment>Short for Classic (2 players)</extracomment>
        <translation>经典（2人）</translation>
    </message>
    <message>
        <source>Classic (3)</source>
        <extracomment>Short for Classic (3 players)</extracomment>
        <translation>经典（3人）</translation>
    </message>
    <message>
        <source>Classic (4)</source>
        <extracomment>Short for Classic (4 players)</extracomment>
        <translation>经典（4人）</translation>
    </message>
    <message>
        <source>Duo</source>
        <translation>双人</translation>
    </message>
    <message>
        <source>Junior</source>
        <translation>初级</translation>
    </message>
    <message>
        <source>Trigon (2)</source>
        <extracomment>Short for Trigon (2 players)</extracomment>
        <translation>六角（2人）</translation>
    </message>
    <message>
        <source>Trigon (3)</source>
        <extracomment>Short for Trigon (3 players)</extracomment>
        <translation>六角（3人）</translation>
    </message>
    <message>
        <source>Trigon (4)</source>
        <extracomment>Short for Trigon (4 players)</extracomment>
        <translation>六角（4人）</translation>
    </message>
    <message>
        <source>Nexos (2)</source>
        <extracomment>Short for Nexos (2 players)</extracomment>
        <translation>线（2人）</translation>
    </message>
    <message>
        <source>Nexos (4)</source>
        <extracomment>Short for Nexos (4 players)</extracomment>
        <translation>线（4人）</translation>
    </message>
    <message>
        <source>Callisto (2)</source>
        <extracomment>Short for Callisto (2 players, 2 colors)</extracomment>
        <translation>八角（2人）</translation>
    </message>
    <message>
        <source>Callisto (2/4)</source>
        <extracomment>Short for Callisto (2 players, 4 colors)</extracomment>
        <translation>八角（2人4色）</translation>
    </message>
    <message>
        <source>Callisto (3)</source>
        <extracomment>Short for Callisto (3 players)</extracomment>
        <translation>八角（3人）</translation>
    </message>
    <message>
        <source>Callisto (4)</source>
        <extracomment>Short for Callisto (4 players)</extracomment>
        <translation>八角（4人）</translation>
    </message>
    <message>
        <source>GembloQ (4)</source>
        <extracomment>Short for GembloQ (4 players)</extracomment>
        <translation>宝石阵Q（4人）</translation>
    </message>
    <message>
        <source>GembloQ (2)</source>
        <extracomment>Short for GembloQ (2 players, 2 colors)</extracomment>
        <translation>宝石阵Q（2人）</translation>
    </message>
    <message>
        <source>GembloQ (2/4)</source>
        <extracomment>Short for GembloQ (2 players, 4 colors)</extracomment>
        <translation>宝石阵Q（2人4色）</translation>
    </message>
    <message>
        <source>GembloQ (3)</source>
        <extracomment>Short for GembloQ (3 players)</extracomment>
        <translation>宝石阵Q（3人）</translation>
    </message>
    <message>
        <source>Rated games:</source>
        <translation>等级赛局数：</translation>
    </message>
    <message>
        <source>Best previous rating:</source>
        <translation>历史最佳等级分：</translation>
    </message>
    <message>
        <source>Recent development:</source>
        <translation>最近的发展：</translation>
    </message>
    <message>
        <source>Open Game %1</source>
        <translation>打开第%1局</translation>
    </message>
</context>
<context>
    <name>SaveDialog</name>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Blokus games</source>
        <translation>角斗士游戏</translation>
    </message>
</context>
<context>
    <name>TableModel</name>
    <message>
        <source>Game</source>
        <extracomment>Table header for game number in rating dialog</extracomment>
        <translation>总局数</translation>
    </message>
    <message>
        <source>Result</source>
        <extracomment>Table header for game result in rating dialog</extracomment>
        <translation>结果</translation>
    </message>
    <message>
        <source>Level</source>
        <extracomment>Table header for level in rating dialog</extracomment>
        <translation>级别</translation>
    </message>
    <message>
        <source>Your Color</source>
        <extracomment>Table header for player color(s) in rating dialog</extracomment>
        <translation>您执</translation>
    </message>
    <message>
        <source>Date</source>
        <extracomment>Table header for game date in rating dialog</extracomment>
        <translation>日期</translation>
    </message>
    <message>
        <source>Win</source>
        <extracomment>Result of rated game is a win</extracomment>
        <translation>胜</translation>
    </message>
    <message>
        <source>Loss</source>
        <extracomment>Result of rated game is a loss</extracomment>
        <translation>负</translation>
    </message>
    <message>
        <source>Tie</source>
        <extracomment>Result of rated game is a tie. Abbreviate long translations to ensure that all columns of rated games list are visible on mobile devices with small screens.</extracomment>
        <translation>平</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>computer opponent for the board game Blokus</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set maximum level to &lt;n&gt;.</source>
        <extracomment>Description for command line option --maxlevel</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not use opening books.</source>
        <extracomment>Description for command line option --nobook</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use layout optimized for smartphones.</source>
        <extracomment>Description for command line option --mobile</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Do not delay fast computer moves.</source>
        <extracomment>Description for command line option --nodelay</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set random seed to &lt;n&gt;.</source>
        <extracomment>Description for command line option --seed</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use &lt;n&gt; threads (0=auto).</source>
        <extracomment>Description for command line option --threads</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Print logging information to standard error.</source>
        <extracomment>Description for command line option --verbose</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>file.blksgf</source>
        <extracomment>Name of command line argument.</extracomment>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Blokus SGF file to open (optional).</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>--maxlevel must be between 1 and %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>--seed must be a positive number</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>--threads must be a positive number</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Too many arguments</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>